@@ -141,7 +141,7 @@ def verify_experiment_module(verbose):
     temp_package_name = "TEMP_VERIFICATION_PACKAGE"
     tmp = tempfile.mkdtemp()
     clone_dir = os.path.join(tmp, temp_package_name)
-    ExperimentFileSource(os.getcwd()).selective_copy_to(clone_dir)
+    ExperimentFileSource(os.getcwd()).apply_to(clone_dir)
     initialize_experiment_package(clone_dir)
     from dallinger_experiment import experiment
 
