@@ -201,6 +201,7 @@ BROWSEABLE_MODELS = [
     "Question",
     "Transformation",
     "Transmission",
+    "Notification",
 ]
 
 
@@ -219,6 +220,7 @@ dashboard_tabs = DashboardTabs(
         DashboardTab("Monitoring", "dashboard.monitoring"),
         DashboardTab("Lifecycle", "dashboard.lifecycle"),
         DashboardTab("Database", "dashboard.database", database_children),
+        DashboardTab("Development", "dashboard.develop"),
     ]
 )
 
@@ -745,6 +747,14 @@ def database():
     )
 
 
+@dashboard.route("/develop", methods=["GET", "POST"])
+@login_required
+def develop():
+    """Dashboard for working with ``dallinger develop`` Flask server."""
+
+    return render_template("dashboard_develop.html")
+
+
 @dashboard.route("/database/action/<route_name>", methods=["POST"])
 @login_required
 def database_action(route_name):
